package xmlcaviargui;

/** Class for representing all boxes so they
 * can be scrolled through without reading them from 
 * disk
 * @author Donald Nairn
 * @version 1.0
 */

public class FrameData {
    
    /** Constants used to represent the number of single or group
     * boxes contained in a FrameData object.
     */
    public static final int GROUP_BOXES = 20, SINGLE_BOXES = 20;

    /** Structures used for storing single box data about the 
     * video frame.
     */   
    public SingleBox[] singleBox = new SingleBox[SINGLE_BOXES]; 
   
    /** Structures used for storing group box data about the 
     * video frame.
     */   
    public GroupBox[] groupBox = new GroupBox[GROUP_BOXES];

    /**
     * Default constructor sets all the data to nothing.
     */
    public FrameData() {
	singleBox = new SingleBox[SINGLE_BOXES];
	for (int i = 0; i < singleBox.length; i++) {
	    singleBox[i] = new SingleBox();
	}
	groupBox = new GroupBox[GROUP_BOXES];
	for (int i = 0; i < groupBox.length; i++) {
	    groupBox[i] = new GroupBox();
	}
	// default set first single box selected
	singleBox[0].setSelected(true);
    }

    /** 
     * Constructor specifying the single boxes and the group boxes
     * to be used for this FrameData object.
     */
    public FrameData(SingleBox[] singleBox, GroupBox[] groupBox) {
	for (int i = 0; i < singleBox.length; i++) {
	    if (!singleBox[i].getBoxDrawn()) {
		this.singleBox[i] = new SingleBox();
	    } else {
		this.singleBox[i] = new SingleBox(singleBox[i].getTruths(),
						  singleBox[i].getBox(),
						  singleBox[i].getAxis(),
						  singleBox[i].getLine(),
						  singleBox[i].getBody());
		if (singleBox[i].getSelected()) this.singleBox[i].setSelected(true);
	    }
	}
	
	for (int i = 0; i < groupBox.length; i++) {
	    if (!groupBox[i].getBoxDrawn()) {
		this.groupBox[i] = new GroupBox();
	    } else {
		this.groupBox[i] = new GroupBox(groupBox[i].getTruths(),
						groupBox[i].getBox(),
						groupBox[i].getAxis(),
						groupBox[i].getLine(),
						groupBox[i].getIndBoxes());
		if (groupBox[i].getSelected()) this.groupBox[i].setSelected(true);
	    }
	}
    }

    /** 
     * Returns the currently selected box, 0-6 (currently) 
     * represent the 7 single boxes and 7-13 represent the 
     * 7 group boxes.
     */
    public int getSelected() {
	for (int i = 0; i < singleBox.length; i++) {
	    if (singleBox[i].getSelected() == true) {
		return i;
	    }
	}
	for (int i = 0; i < groupBox.length; i++) {
	    if (groupBox[i].getSelected() == true) {
		return i + SINGLE_BOXES;
	    }
	}
	
	// default return first single box
	return 0;
    }
    
    /**
     * Returns the SingleBox object at index i in this FrameData object.
     */
    public SingleBox getSingleBox(int i) {
	return singleBox[i];
    }
    
    /**
     * Returns the array of all SingleBox objects in this FrameData object.
     */
    public SingleBox[] getSingleBoxes() {
	return singleBox;
    }

    /**
     * Returns the GroupBox object at index i in this FrameData object.
     */
    public GroupBox getGroupBox(int i) {
	return groupBox[i];
    }

    /** 
     * Returns the array of all GroupBox objects in this FrameData object.
     */
    public GroupBox[] getGroupBoxes() {
	return groupBox;
    }

    /**
     * Returns the String representation of this FrameData object.
     */
    public String toString() {
	// beginning of ib list
	String returnString = "ibl"/*+"\n"*/+"\t";
	// add all single boxes so can be written to a file
	for (int i = 0; i < singleBox.length; i++) {
	    if (singleBox[i] != null && singleBox[i].getBoxDrawn()) {
		returnString = returnString+"ib\t" + i + "\t" + singleBox[i].toString() + "\teib"/*+"\n"*/+"\t";
	    }
	}
	// end of ib list
	returnString = returnString + "eibl"/*+"\n"*/+"\t";
	// beginning of gb list
	returnString = returnString + "gbl"/*+"\n"*/+"\t";
	// add all group boxes so can be written to a file
	for (int i = 0; i < groupBox.length; i++) {
	    if (groupBox != null && groupBox[i].getBoxDrawn()) {
		returnString = returnString+"gb\t" + i + "\t" + groupBox[i].toString();

		/* TAKEN OUT FOR TIME BEING */
		// for each group box add all single and group  boxes that are fully contained
		// the single box
		/*for (int j = 0; j < singleBox.length; j++) {
		  if (singleBox[j] != null && singleBox[j].getBoxDrawn()) {
		  if (singleBox[j].getBox().getX() > groupBox[i].getBox().getX() &&
		  singleBox[j].getBox().getY() > groupBox[i].getBox().getY() &&
		  singleBox[j].getBox().getWidth() < groupBox[i].getBox().getWidth() &&
		  singleBox[j].getBox().getHeight() < groupBox[i].getBox().getHeight())
		  returnString = returnString + " ib " + j + " eib";
		  }
		  }
		  for (int j = 0; j < groupBox.length; j++) {
		  if (groupBox[j] != null && i != j && groupBox[j].getBoxDrawn()) {
		  if (groupBox[j].getBox().getX() > groupBox[i].getBox().getX() &&
		  groupBox[j].getBox().getY() > groupBox[i].getBox().getY() &&
		  groupBox[j].getBox().getWidth() < groupBox[i].getBox().getWidth() &&
		  groupBox[j].getBox().getHeight() < groupBox[i].getBox().getHeight())
		  returnString = returnString +  "gb " + j + "gib";
		  }
		  }*/

		returnString = returnString + "\tegb"/*+"\n"*/+"\t";
	    }
	}
	returnString = returnString + "egbl"/*+"\n"*/+"\t";
	return returnString;
    }

	public void printFrame(int frame){
		boolean PROBLEMS=false;
		for (int i=0;i<singleBox.length;i++)
			if (singleBox[i].isDefault()==false){
				String s=singleBox[i].CheckRoles();
				if (s!=null){
					if (PROBLEMS==false){
						System.out.println("\n Frame Number "+frame);
						PROBLEMS=true;
					}
					System.out.println(" SingleBox "+i+" Roles: "+s);
				}
				
				s=singleBox[i].CheckSituations();
				if (s!=null){
					if (PROBLEMS==false){
						System.out.println("\n Frame Number "+frame);
						PROBLEMS=true;
					}
					System.out.println(" SingleBox "+i+" Situations: "+s);
				}
				
				s=singleBox[i].CheckScenarios();
				if (s!=null){
					if (PROBLEMS==false){
						System.out.println("\n Frame Number "+frame);
						PROBLEMS=true;
					}
					System.out.println(" SingleBox "+i+" Scenarios: "+s);
				}
			}		

		for (int i=0;i<groupBox.length;i++)
			if (groupBox[i].isDefault()==false){
				String s=groupBox[i].CheckRoles();
				if (s!=null){
					if (PROBLEMS==false){
						System.out.println("\n Frame Number "+frame);
						PROBLEMS=true;
					}
					System.out.println(" GroupBox "+i+" Roles: "+s);
				}
				
				s=groupBox[i].CheckSituations();
				if (s!=null){
					if (PROBLEMS==false){
						System.out.println("\n Frame Number "+frame);
						PROBLEMS=true;
					}
					System.out.println(" GroupBox "+i+" Situations: "+s);
				}
				
				s=groupBox[i].CheckScenarios();
				if (s!=null){
					if (PROBLEMS==false){
						System.out.println("\n Frame Number "+frame);
						PROBLEMS=true;
					}
					System.out.println(" GroupBox "+i+" Scenarios: "+s);
				}
			}
	}
	
	public void setProperty(boolean ind, String Property, String value,int id){
		if (ind==true){
			if (Property.equals("-rol"))
				singleBox[id].setRol(value);
			if (Property.equals("-situation"))
				singleBox[id].setSituation(value);	
			if (Property.equals("-scenario"))
				singleBox[id].setScenario(value);
		}else{
			if (Property.equals("-rol"))
				groupBox[id].setRol(value);
			if (Property.equals("-situation"))
				groupBox[id].setSituation(value);	
			if (Property.equals("-scenario"))
				groupBox[id].setScenario(value);		
		}
	}
			

}
