package xmlcaviargui;


import java.awt.*;
import java.awt.geom.*;

/**
 * Class for representing a group of people box.
 * @author Donald Nairn
 * @version 1.0
 */

public class GroupBox {

    /** Axis of orientation of a person */ 
    private int axis;
    
    /** Axis line drawn on the DrawCanvas object
     */
    private Line2D.Float axisLine;

    /** 
     * Used to determine which part in the truths array is relavent to
     * which of the boolean attributes of a frame.
     */
    public static final int APPEAR = 0, DISAPPEAR = 1, 
    /* GROUP MOVEMENTS */
	ACTIVE = 2, INACTIVE  = 3, MOVE = 4, 
	/* GROUP ROLES */
	FIGHTERS = 5, MEETERS = 6, WALKERS = 7, 
	GRBROWSER_ROLE=28,GRLEFTOBJECT_ROLE=31,GRLEFTVICTIM_ROLE=32,
	
	/* SITUATIONS */
	GR_FIGHTING = 8, GR_MOVING = 9, GR_MEETING = 10, GR_SPLITTING = 11,
	GR_INACTIVE = 12, GR_LEFT_VICTIM = 13, GR_LEFT_OBJECT = 14,GR_INTERACTING = 21,
	GRSHOPENTER_SIT=22,GRSHOPEXIT_SIT=23,GRBROWSING_SIT=30,	
	
	/* EVENTS*/
	FIGHT_START = 18, FIGHT_END = 19, FIGHT_VICTIM_LEFT = 20, 
	
	/* SCENARIOS */
	FIGHTING = 15, MEETING = 16, LEAVING = 17,
	GRWINDOWSHOP_SCE=24,GRSHOPENTER_SCE=25,GRSHOPEXIT_SCE=26,GRSHOPREENTER_SCE=27,
	GRWALKING_SCE=29,
	
	 /*DEFAULT VALUES*/
	NONE_ROLE=33,NONE_SIT=34,NONE_SCE=35, NONE_MOV=36;/*PTC*/
	
    /**The following is used by ChangeBoxSequence and if not kept up to date with the above will
      * cause the program not to function correctly
      */

    public static String[] text = {"appear", "disappear", "active", "inactive", "movement",
	"fighters", "meeters", "walkers", "fighting", "moving", "joining", "split up", 
	"inactive", "leaving victim", "leaving object", "fighting", "meeting", "leaving object",
	"fight start", "fight end", "left victim", "interacting", "shop enter", "shop exit",
	"windopshop", "shop enter", "shop exit", "shop reenter", "browsers", "walking", 
	"browsing", "leaving object", "leaving victim", "none", "none", "none", "none"};

    public static int[] roles = {FIGHTERS, MEETERS, WALKERS, GRBROWSER_ROLE, GRLEFTOBJECT_ROLE,
	GRLEFTVICTIM_ROLE, NONE_ROLE};

    public static int[] scenarios = {FIGHTING, MEETING, LEAVING, GRWINDOWSHOP_SCE, GRSHOPENTER_SCE,
	GRSHOPEXIT_SCE, GRSHOPREENTER_SCE, GRWALKING_SCE, NONE_SCE};

    public static int[] situations = {GR_FIGHTING, GR_MOVING, GR_MEETING, GR_SPLITTING, GR_INACTIVE,
	 GR_LEFT_VICTIM, GR_LEFT_OBJECT, GR_INTERACTING, GRSHOPENTER_SIT, GRSHOPEXIT_SIT, 
	 GRBROWSING_SIT, NONE_SIT};

    public static int[] movements = {ACTIVE, INACTIVE, MOVE, NONE_MOV};
    /**
     * The number of truths in the ground truths array.
     */
    public static final int LENGTH = 37;

    /**
     * Variable representing the number of group movement variables
     */
    public static final int MOVEMENT_LENGTH = 4;

    /**
     * Variable representing the number of role variables
     */
    public static final int ROLE_LENGTH = 7;

    /**
     * Variable representing the number of situation variables
     */
    public static final int SIT_LENGTH = 12;

    /**
     * Variable representing the number of scenario variables
     */
    public static final int SCE_LENGTH = 9;

    /** 
     * Truths array to represent everything that is known about a picture.
     */
    public boolean truths[] = new boolean[LENGTH];
    

    /**
     * Array representing the single boxes in this GroupBox object
     */
    public boolean indBoxes[] = new boolean[FrameData.SINGLE_BOXES];

    /** 
     * Flag to indicate box whether the box has been drawn on the canvas
     */
    private boolean boxDrawn;

    /** Flag to inidicate whether the box has been selected by the user
     */
    private boolean selected;
    
    /** Retangle object used to represent the box that has been drawn on the canvas
     */
    private Rectangle box;

    /** 
     * Default constructor, everything in the truths array is set to false
     * and the box is not drawn and the orientation axis is set to default of
     * 90 degrees
     */
    public GroupBox() {
	for (int i = 0; i < truths.length; i++) {
	    truths[i] = false;
	}
	// default inactive and meet
	truths[NONE_MOV] = true;
	truths[NONE_SIT] = true;
	truths[NONE_ROLE] = true;
	truths[NONE_SCE]=true;
	axis = 90;
	boxDrawn = false;
	selected = false;
	box = null;
	axisLine = new Line2D.Float();
	for (int i = 0; i < indBoxes.length; i++) {
	    indBoxes[i] = false;
	}
    }

   /** 
     * Checks if the Groupbox has the default values in all the fields.
     */	
	public boolean isDefault(){
	boolean empty=true;
	for (int i = 0; i < truths.length; i++) 
	if ((i!=NONE_ROLE) && (i!=NONE_SIT) && (i!=NONE_MOV) && (i!=NONE_SCE) && (truths[i]!=false))
		empty=false;
	if (truths[NONE_ROLE]!=true)
		empty=false;
	if (truths[NONE_SIT]!=true)
		empty=false;
	if (truths[NONE_MOV]!=true)
		empty=false;
	if (truths[NONE_SCE]!=true)
		empty=false;		
	if (axis!=90)
		empty=false;
	if (boxDrawn!=false)
		empty=false;
	if (box!=null)
		empty=false;
	for (int i = 0; i < indBoxes.length; i++)
		if (indBoxes[i]!=false)
			empty=false;
	return empty;	
	}    

    /** Used when loading a new file from disk, a new object is created with
     * the proper truths, box, axis and axisLine attirbutes specified.
     */
    public GroupBox(boolean[] truths, Rectangle box, int axis, Line2D.Float axisLine, boolean[] indBoxes) {
	for (int i = 0; i < truths.length; i++) {
	    this.truths[i] = truths[i];
	}
	this.box = box;
	this.axis = axis;
	this.axisLine = axisLine;
	boxDrawn = true;
	for (int i = 0; i < indBoxes.length; i++) {
	    this.indBoxes[i] = indBoxes[i];
	}
    }


    /** 
     * Get method for GUI to get value of appear
     * value in truths array. 
     */
    public boolean getAppear() {
	return truths[APPEAR];	
    }

    /** 
     * Get method for GUI to get value of disappear
     * value in truths array. 
     */
    public boolean getDisappear() {
	return truths[DISAPPEAR];
    }
    
    /** 
     * Get method for GUI to get value of active
     * value in truths array. 
     */
    public boolean getActive() {
	return truths[ACTIVE];
    }

    /** 
     * Get method for GUI to get value of inactive
     * value in truths array. 
     */
    public boolean getInActive() {
	return truths[INACTIVE];
    }
    
    /** 
     * Get method for GUI to get value of move
     * value in truths array. 
     */
    public boolean getMove() {
	return truths[MOVE];
    }

    /** 
     * Get method for GUI to get value of none movement
     * value in truths array. 
     */
    public boolean getNoneMov() {
	return truths[NONE_MOV];
    }

    /**
     * Get method for GUI to get value of none rol 
     * value in truths array. 
     */
    public boolean getNoneRol() {
	return truths[NONE_ROLE];
    }

    
    /**
     * Get method for GUI to get value of fight 
     * value in truths array. 
     */
    public boolean getFight() {
	return truths[FIGHTERS];
    }
    
    /**
     * Get method for GUI to get value of meet
     * value in truths array. 
     */
    public boolean getMeet() {
	return truths[MEETERS];
    }

    /** 
     * Returns the value of walkers in truths array
     */
    public boolean getWalk() {
	return truths[WALKERS];
    }
    
    /**
     * Returns the value of group fighters in truths array
     */
    public boolean getGrFighting() {
	return truths[GR_FIGHTING];
    }

    /** 
     * Get method for GUI to get value of none situation
     * value in truths array. 
     */
    public boolean getNoneSit() {
	return truths[NONE_SIT];
    }

    /**
     * Returns the value of browsing situation in truths array
     */
    public boolean getBrowsingSit() {
	return truths[GRBROWSING_SIT];
    }

    /**
     * Returns the value of shop enter situation in truths array
     */
    public boolean getShopenterSit() {
	return truths[GRSHOPENTER_SIT];
    }

    /**
     * Returns the value of shop exit situation in truths array
     */
    public boolean getShopexitSit() {
	return truths[GRSHOPEXIT_SIT];
    }

    /** 
     * Get method for GUI to get value of none scenario
     * value in truths array. 
     */
    public boolean getNoneSce() {
	return truths[NONE_SCE];
    }

    /**
     * Returns the value of window shop scenario in truths array
     */
    public boolean getWindowshopSce() {
	return truths[GRWINDOWSHOP_SCE];
    }
    
    /**
     * Returns the value of shop enter scenario in truths array
     */
    public boolean getShopenterSce() {
	return truths[GRSHOPENTER_SCE];
    }
    
    /**
     * Returns the value of shop exit scenario in truths array
     */
    public boolean getShopexitSce() {
	return truths[GRSHOPEXIT_SCE];
    } 

    /**
     * Returns the value of shop reenter scenario in truths array
     */
    public boolean getShopreenterSce() {
	return truths[GRSHOPREENTER_SCE];
    }    

    /**
     * Returns the value of browser role in truths array
     */
    public boolean getBrowserRole() {
	return truths[GRBROWSER_ROLE];
    } 

    /**
     * Returns the value of walking scenario in truths array
     */
    public boolean getWalkingSce() {
	return truths[GRWALKING_SCE];
    } 
        
    /** 
     * Returns the value of group moving in truths array
     */
    public boolean getGrMoving() {
	return truths[GR_MOVING];
    }

    /**
     * Returns the value of group meeting in truths array
     */
    public boolean getGrMeeting() {
	return truths[GR_MEETING];
    }
    
     /**
     * Returns the value of group meeting in truths array
     */
    public boolean getGrInteracting() {
	return truths[GR_INTERACTING];
    }


    /**
     * Returns the value of group splitting in truths array
     */
    public boolean getGrSplitting() {
	return truths[GR_SPLITTING];
    }
    
    /**
     * Returns the value of group inactive in truths array
     */
    public boolean getGrInactive() {
	return truths[GR_INACTIVE];
    }

    /**
     * Get method for GUI to get value of left behind 
     * value in truths array. 
     */
    public boolean getLeftBehind() {
	return truths[GR_LEFT_VICTIM];
    }

    /**
     * Get method for GUI to get value of left object  
     * value in truths array. 
     */
    public boolean getLeftObject() {
	return truths[GR_LEFT_OBJECT];
    }

    /**
     * Returns the value of fighting in truths array
     */
    public boolean getFighting() {
	return truths[FIGHTING];
    }

    /**
     * Returns the value of meeting in truths array
     */
    public boolean getMeeting() {
	return truths[MEETING];
    }

    /**
     * Returns the value of leaving in truths array
     */
    public boolean getLeaving() {
	return truths[LEAVING];
    }
    

    /**
     * Returns the value of fight start in truths array
     */
    public boolean getFightStart() {
	return truths[FIGHT_START];
    }

    /**
     * Returns the value of fight end in truths array
     */
    public boolean getFightEnd() {
	return truths[FIGHT_END];
    }

    /**
     * Returns the value of fight left victim in truths array
     */
    public boolean getFightVictimLeft() {
	return truths[FIGHT_VICTIM_LEFT];
    }

    /**
     * Get method for GUI to get whether a box 
     * has been drawn asscociated with this GroupBox object 
     */
    public boolean getBoxDrawn() {
	return boxDrawn;
    }

     /**
     * Get method for GUI to get whether a this GroupBox object
     * has been selected by the user.
     */
    public boolean getSelected() {
	return selected;
    }

    /**
     * get method for the GUI to return the Rectangle object associated
     * with this GroupBox object.
     */
    public Rectangle getBox() {
	return box;
    }

    /**
     * Returns the axis of orientation assciated with this GroupBox object.
     */
    public int getAxis() {
	return axis;
    }

    /**
     * Returns the line of the orientation worked out from the
     * Rectangle object and the axis parameter if this GroupBox object.
     */
    public Line2D.Float getLine() {
	return axisLine;
    }
    
    /**
     * Returns all the truths asscoiated with this GroupBox object.
     */
    public boolean[] getTruths() {
	return truths;
    }

    /**
     * Returns a boolean variable representing true if a single box is associated with this groupbox and false otherwise
     */
    public boolean getIndBoxAt(int i) {
	return indBoxes[i];
    }


    /**
     * Gets the array rep the individual boxes that are included in this group box
     */
    public boolean[] getIndBoxes() {
	return indBoxes;
    }

    /** 
     * Toggles the value of the appear attribute of this GroupBox object.
     */
    public void setAppear() {
	truths[APPEAR] = !truths[APPEAR];
	if (truths[APPEAR] == true && truths[APPEAR] == truths[DISAPPEAR]) {
	    setDisappear();
	}
    }
    
    /** 
     * Toggles the value of the disappear attribute of this GroupBox object.
     */
    public void setDisappear() {
	truths[DISAPPEAR] = !truths[DISAPPEAR];
	if (truths[DISAPPEAR] == true && truths[DISAPPEAR] == truths[APPEAR]) {
	    setAppear();
	}
    }
    
    /** 
     * Toggles the value of the active attribute of this GroupBox object.
     */
    public void setActive() {
	truths[ACTIVE] = !truths[ACTIVE];
//     System.out.println("setting  gr active "+truths[ACTIVE]);    	
	if (truths[ACTIVE] == true) {
	    if(truths[ACTIVE] == truths[NONE_MOV]){
		setNoneMov();
	    }
	    if (truths[ACTIVE] == truths[INACTIVE]) {
		setInActive();
	    }
	    if (truths[ACTIVE] == truths[MOVE]) {
		setMove();
	    }
	}
    }

    /** 
     * Toggles the value of the inactive attribute of this GroupBox object.
     */
    public void setInActive() {
	truths[INACTIVE] = !truths[INACTIVE];
//    System.out.println("setting  gr inactive "+truths[INACTIVE]);    	
	if (truths[INACTIVE] == true) {
	    if(truths[INACTIVE] == truths[NONE_MOV]){
		setNoneMov();
	    }
	    if (truths[INACTIVE] == truths[ACTIVE]) {
		setActive();
	    }
	    if (truths[INACTIVE] == truths[MOVE]) {
		setMove();
	    }
	}
    }

    /** 
     * Toggles the value of the move attribute of this GroupBox object.
     */
    public void setMove() {
	truths[MOVE] = !truths[MOVE];
 //   System.out.println("setting  gr move "+truths[MOVE]);
	if (truths[MOVE] == true) {
	    if(truths[MOVE] == truths[NONE_MOV]){
		setNoneMov();
	    }
	    if (truths[MOVE] == truths[INACTIVE]) {
		setInActive();
	    }
	    if (truths[MOVE] == truths[ACTIVE]) {
		setActive();
	    }
	}
    }

    /** 
     * Toggles the value of the none movement attribute of this GroupBox object.
     */
    public void setNoneMov() {
	truths[NONE_MOV] = !truths[NONE_MOV];
//    System.out.println("setting  gr nomove "+truths[NONE_MOV]);   
	if (truths[NONE_MOV] == true) {
	    if(truths[NONE_MOV] == truths[MOVE]){
		setMove();
	    }
	    if (truths[NONE_MOV] == truths[INACTIVE]) {
		setInActive();
	    }
	    if (truths[NONE_MOV] == truths[ACTIVE]) {
		setActive();
	    }
	}
    }

    /** 
     * Toggles the value of the none rol attribute of this GroupBox object.
     */
    public void setNoneRol() {
	truths[NONE_ROLE] = !truths[NONE_ROLE];
	if (truths[NONE_ROLE] == true) {
	    if (truths[NONE_ROLE] == truths[FIGHTERS]) {
		setFight();
	    }
	    if (truths[NONE_ROLE] == truths[GRBROWSER_ROLE]) {
		setBrowserRole();
	    }
	    if (truths[NONE_ROLE] == truths[MEETERS]) {
		setMeet();
	    }
	    if (truths[NONE_ROLE] == truths[WALKERS]) {
		setWalk();
	    }
	    	}
    }

    /** 
     * Toggles the value of the fight attribute of this GroupBox object.
     */
    public void setFight() {
	truths[FIGHTERS] = !truths[FIGHTERS];
	if (truths[FIGHTERS] == true) {
	    if (truths[FIGHTERS] == truths[NONE_ROLE]) {
		setNoneRol();
	    }
	    if (truths[FIGHTERS] == truths[GRBROWSER_ROLE]) {
		setBrowserRole();
	    }
	    if (truths[FIGHTERS] == truths[MEETERS]) {
		setMeet();
	    }
	    if (truths[FIGHTERS] == truths[WALKERS]) {
		setWalk();
	    }
	 }	
    }
    
    /** 
     * Toggles the value of the meet attribute of this GroupBox object.
     */
    public void setMeet() {
	truths[MEETERS] = !truths[MEETERS];
	if (truths[MEETERS] == true) {
	    if (truths[MEETERS] == truths[NONE_ROLE]) {
		setNoneRol();
	    }
	    if (truths[MEETERS] == truths[GRBROWSER_ROLE]) {
		setBrowserRole();
	    }
	    if (truths[MEETERS] == truths[FIGHTERS]) {
		setFight();
	    }
	    if (truths[MEETERS] == truths[WALKERS]) {
		setWalk();
	    }	
	 }
    }

     /** 
     * Toggles the value of the walkers attribute of this GroupBox object.
     */
    public void setWalk() {
	truths[WALKERS] = !truths[WALKERS];
	if (truths[WALKERS] == true) {
	    if (truths[WALKERS] == truths[NONE_ROLE]) {
		setNoneRol();
	    }
	    if (truths[WALKERS] == truths[GRBROWSER_ROLE]) {
		setBrowserRole();
	    }
	    if (truths[WALKERS] == truths[FIGHTERS]) {
		setFight();
	    }
	    if (truths[WALKERS] == truths[MEETERS]) {
		setMeet();
	    }	
	 }
    }

     /** 
     * Toggles the value of the shop enter situation attribute of this GroupBox object.
     */
    public void setShopenterSit() {
	truths[GRSHOPENTER_SIT] = !truths[GRSHOPENTER_SIT];
	if (truths[GRSHOPENTER_SIT] == true) {
	    if(truths[GRSHOPENTER_SIT] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GRSHOPENTER_SIT] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GRSHOPENTER_SIT] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GRSHOPENTER_SIT] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GRSHOPENTER_SIT] == truths[GR_MEETING]) {
		setGrMeeting();
	    }	
	    if (truths[GRSHOPENTER_SIT] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }
	    if (truths[GRSHOPENTER_SIT] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }			    
	    if (truths[GRSHOPENTER_SIT] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }
	    if (truths[GRSHOPENTER_SIT] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }
	    if (truths[GRSHOPENTER_SIT] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }			
	    if (truths[GRSHOPENTER_SIT] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }

    }

     /** 
     * Toggles the value of the shop exit situation attribute of this GroupBox object.
     */
    public void setShopexitSit() {
	truths[GRSHOPEXIT_SIT] = !truths[GRSHOPEXIT_SIT];
	if (truths[GRSHOPEXIT_SIT] == true) {
	    if(truths[GRSHOPEXIT_SIT] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GRSHOPEXIT_SIT] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GRSHOPEXIT_SIT] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GRSHOPEXIT_SIT] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GRSHOPEXIT_SIT] == truths[GR_MEETING]) {
		setGrMeeting();
	    }	
	    if (truths[GRSHOPEXIT_SIT] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }
	    if (truths[GRSHOPEXIT_SIT] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }			    
	    if (truths[GRSHOPEXIT_SIT] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }
	    if (truths[GRSHOPEXIT_SIT] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GRSHOPEXIT_SIT] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }			
	    if (truths[GRSHOPEXIT_SIT] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }
    }

     /** 
     * Toggles the value of the window shop scenario attribute of this GroupBox object.
     */
    public void setWindowshopSce() {
	truths[GRWINDOWSHOP_SCE] = !truths[GRWINDOWSHOP_SCE];
	if (truths[GRWINDOWSHOP_SCE] == true) {
	    if (truths[GRWINDOWSHOP_SCE] == truths[NONE_SCE]) {
		setNoneSce();
	    }
	    if (truths[GRWINDOWSHOP_SCE] == truths[FIGHTING]) {
		setFighting();
	    }
	    if (truths[GRWINDOWSHOP_SCE] == truths[GRWALKING_SCE]) {
		setWalkingSce();
	    }
	    if (truths[GRWINDOWSHOP_SCE] == truths[MEETING]) {
		setMeeting();
	    }
	    if (truths[GRWINDOWSHOP_SCE] == truths[GRSHOPENTER_SCE]) {
		setShopenterSce();
	    }	
	    if (truths[GRWINDOWSHOP_SCE] == truths[GRSHOPEXIT_SCE]) {
		setShopexitSce();
	    }
	    if (truths[GRWINDOWSHOP_SCE] == truths[GRSHOPREENTER_SCE]) {
		setShopreenterSce();
	    }			    
	    if (truths[GRWINDOWSHOP_SCE] == truths[LEAVING]) {
		setLeaving();
	    }
	 }	
    }

     /** 
     * Toggles the value of the browsing situation attribute of this GroupBox object.
     */
    public void setBrowsingSit() {
	truths[GRBROWSING_SIT] = !truths[GRBROWSING_SIT];
	if (truths[GRBROWSING_SIT] == true) {
	    if(truths[GRBROWSING_SIT] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GRBROWSING_SIT] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GRBROWSING_SIT] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GRBROWSING_SIT] == truths[GR_MEETING]) {
		setGrMeeting();
	    }
	    if (truths[GRBROWSING_SIT] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }	
	    if (truths[GRBROWSING_SIT] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }
	    if (truths[GRBROWSING_SIT] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }			    
	    if (truths[GRBROWSING_SIT] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GRBROWSING_SIT] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }
	    if (truths[GRBROWSING_SIT] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }			
	    if (truths[GRBROWSING_SIT] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }
    }

     /** 
     * Toggles the value of the shop enter scenario attribute of this GroupBox object.
     */
    public void setShopenterSce() {
	truths[GRSHOPENTER_SCE] = !truths[GRSHOPENTER_SCE];
	if (truths[GRSHOPENTER_SCE] == true) {
	    if (truths[GRSHOPENTER_SCE] == truths[NONE_SCE]) {
		setNoneSce();
	    }
	    if (truths[GRSHOPENTER_SCE] == truths[FIGHTING]) {
		setFighting();
	    }
	    if (truths[GRSHOPENTER_SCE] == truths[GRWALKING_SCE]) {
		setWalkingSce();
	    }
	    if (truths[GRSHOPENTER_SCE] == truths[MEETING]) {
		setMeeting();
	    }
	    if (truths[GRSHOPENTER_SCE] == truths[GRWINDOWSHOP_SCE]) {
		setWindowshopSce();
	    }	
	    if (truths[GRSHOPENTER_SCE] == truths[GRSHOPEXIT_SCE]) {
		setShopexitSce();
	    }
	    if (truths[GRSHOPENTER_SCE] == truths[GRSHOPREENTER_SCE]) {
		setShopreenterSce();
	    }			    
	    if (truths[GRSHOPENTER_SCE] == truths[LEAVING]) {
		setLeaving();
	    }
	 }		
    }

     /** 
     * Toggles the value of the shop exit scenario attribute of this GroupBox object.
     */
    public void setShopexitSce() {
	truths[GRSHOPEXIT_SCE] = !truths[GRSHOPEXIT_SCE];
	if (truths[GRSHOPEXIT_SCE] == true) {
	    if (truths[GRSHOPEXIT_SCE] == truths[NONE_SCE]) {
		setNoneSce();
	    }
	    if (truths[GRSHOPEXIT_SCE] == truths[FIGHTING]) {
		setFighting();
	    }
	    if (truths[GRSHOPEXIT_SCE] == truths[GRWALKING_SCE]) {
		setWalkingSce();
	    }
	    if (truths[GRSHOPEXIT_SCE] == truths[MEETING]) {
		setMeeting();
	    }
	    if (truths[GRSHOPEXIT_SCE] == truths[GRWINDOWSHOP_SCE]) {
		setWindowshopSce();
	    }	
	    if (truths[GRSHOPEXIT_SCE] == truths[GRSHOPENTER_SCE]) {
		setShopenterSce();
	    }
	    if (truths[GRSHOPEXIT_SCE] == truths[GRSHOPREENTER_SCE]) {
		setShopreenterSce();
	    }			    
	    if (truths[GRSHOPEXIT_SCE] == truths[LEAVING]) {
		setLeaving();
	    }
	 }
    }
        
     /** 
     * Toggles the value of the shop reenter scenario attribute of this GroupBox object.
     */
    public void setShopreenterSce() {
	truths[GRSHOPREENTER_SCE] = !truths[GRSHOPREENTER_SCE];
	if (truths[GRSHOPREENTER_SCE] == true) {
	    if (truths[GRSHOPREENTER_SCE] == truths[NONE_SCE]) {
		setNoneSce();
	    }
	    if (truths[GRSHOPREENTER_SCE] == truths[FIGHTING]) {
		setFighting();
	    }
	    if (truths[GRSHOPREENTER_SCE] == truths[GRWALKING_SCE]) {
		setWalkingSce();
	    }
	    if (truths[GRSHOPREENTER_SCE] == truths[MEETING]) {
		setMeeting();
	    }
	    if (truths[GRSHOPREENTER_SCE] == truths[GRWINDOWSHOP_SCE]) {
		setWindowshopSce();
	    }	
	    if (truths[GRSHOPREENTER_SCE] == truths[GRSHOPENTER_SCE]) {
		setShopenterSce();
	    }
	    if (truths[GRSHOPREENTER_SCE] == truths[GRSHOPEXIT_SCE]) {
		setShopexitSce();
	    }			    
	    if (truths[GRSHOPREENTER_SCE] == truths[LEAVING]) {
		setLeaving();
	    }
	 }	
    }

     /** 
     * Toggles the value of the browser role attribute of this GroupBox object.
     */
    public void setBrowserRole() {
	truths[GRBROWSER_ROLE] = !truths[GRBROWSER_ROLE];
	if (truths[GRBROWSER_ROLE] == true) {
	    if (truths[GRBROWSER_ROLE] == truths[NONE_ROLE]) {
		setNoneRol();
	    }
	    if (truths[GRBROWSER_ROLE] == truths[WALKERS]) {
		setWalk();
	    }
	    if (truths[GRBROWSER_ROLE] == truths[FIGHTERS]) {
		setFight();
	    }
	    if (truths[GRBROWSER_ROLE] == truths[MEETERS]) {
		setMeet();
	    }	
	 }
    }

     /** 
     * Toggles the value of the walking scenario attribute of this GroupBox object.
     */
    public void setWalkingSce() {
	truths[GRWALKING_SCE] = !truths[GRWALKING_SCE];
	if (truths[GRWALKING_SCE] == true) {
	    if (truths[GRWALKING_SCE] == truths[NONE_SCE]) {
		setNoneSce();
	    }
	    if (truths[GRWALKING_SCE] == truths[FIGHTING]) {
		setFighting();
	    }
	    if (truths[GRWALKING_SCE] == truths[MEETING]) {
		setMeeting();
	    }
	    if (truths[GRWALKING_SCE] == truths[GRWINDOWSHOP_SCE]) {
		setWindowshopSce();
	    }
	    if (truths[GRWALKING_SCE] == truths[GRSHOPENTER_SCE]) {
		setShopenterSce();
	    }	
	    if (truths[GRWALKING_SCE] == truths[GRSHOPEXIT_SCE]) {
		setShopexitSce();
	    }
	    if (truths[GRWALKING_SCE] == truths[GRSHOPREENTER_SCE]) {
		setShopreenterSce();
	    }			    
	    if (truths[GRWALKING_SCE] == truths[LEAVING]) {
		setLeaving();
	    }
	 }
    }
        
     /** 
     * Toggles the value of the group fighting attribute of this GroupBox object.
     */
    public void setGrFighting() {
	truths[GR_FIGHTING] = !truths[GR_FIGHTING];
	if (truths[GR_FIGHTING] == true) {
	    if(truths[GR_FIGHTING] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GR_FIGHTING] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GR_FIGHTING] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GR_FIGHTING] == truths[GR_MEETING]) {
		setGrMeeting();
	    }
	    if (truths[GR_FIGHTING] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }	
	    if (truths[GR_FIGHTING] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }
	    if (truths[GR_FIGHTING] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }			    
	    if (truths[GR_FIGHTING] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GR_FIGHTING] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }
	    if (truths[GR_FIGHTING] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }			
	    if (truths[GR_FIGHTING] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }
    }

    /** 
     * Toggles the value of the moving attribute of this GroupBox object.
     */
    public void setGrMoving() {
	truths[GR_MOVING] = !truths[GR_MOVING];
	if (truths[GR_MOVING] == true) {
	    if(truths[GR_MOVING] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GR_MOVING] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GR_MOVING] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GR_MOVING] == truths[GR_MEETING]) {
		setGrMeeting();
	    }
	    if (truths[GR_MOVING] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }	
	    if (truths[GR_MOVING] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }
	    if (truths[GR_MOVING] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }			    
	    if (truths[GR_MOVING] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GR_MOVING] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }
	    if (truths[GR_MOVING] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }			
	    if (truths[GR_MOVING] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }
    }

    /** 
     * Toggles the value of the group meeting attribute of this GroupBox object.
     */
    public void setGrMeeting() {
	truths[GR_MEETING] = !truths[GR_MEETING];
	if (truths[GR_MEETING] == true) {
	    if(truths[GR_MEETING] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GR_MEETING] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GR_MEETING] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GR_MEETING] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GR_MEETING] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }	
	    if (truths[GR_MEETING] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }
	    if (truths[GR_MEETING] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }			    
	    if (truths[GR_MEETING] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GR_MEETING] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }
	    if (truths[GR_MEETING] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }			
	    if (truths[GR_MEETING] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }
    }

    /** 
     * Toggles the value of the group meeting attribute of this GroupBox object.
     */
    public void setGrInteracting() {
	truths[GR_INTERACTING] = !truths[GR_INTERACTING];
	if (truths[GR_INTERACTING] == true) {
	    if(truths[GR_INTERACTING] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GR_INTERACTING] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GR_INTERACTING] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GR_INTERACTING] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GR_INTERACTING] == truths[GR_MEETING]) {
		setGrMeeting();
	    }	
	    if (truths[GR_INTERACTING] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }
	    if (truths[GR_INTERACTING] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }			    
	    if (truths[GR_INTERACTING] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GR_INTERACTING] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }
	    if (truths[GR_INTERACTING] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }			
	    if (truths[GR_INTERACTING] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }
    }


    /** 
     * Toggles the value of the splitting attribute of this GroupBox object.
     */
    public void setGrSplitting() {
	truths[GR_SPLITTING] = !truths[GR_SPLITTING];
	if (truths[GR_SPLITTING] == true) {
	    if(truths[GR_SPLITTING] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GR_SPLITTING] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GR_SPLITTING] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GR_SPLITTING] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GR_SPLITTING] == truths[GR_MEETING]) {
		setGrMeeting();
	    }	
	    if (truths[GR_SPLITTING] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }
	    if (truths[GR_SPLITTING] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }			    
	    if (truths[GR_SPLITTING] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GR_SPLITTING] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }
	    if (truths[GR_SPLITTING] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }			
	    if (truths[GR_SPLITTING] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }
    }

    /** 
     * Toggles the value of the inactive attribute of this GroupBox object.
     */
    public void setGrInactive() {
	truths[GR_INACTIVE] = !truths[GR_INACTIVE];
	if (truths[GR_INACTIVE] == true) {
	    if(truths[GR_INACTIVE] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GR_INACTIVE] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GR_INACTIVE] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GR_INACTIVE] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GR_INACTIVE] == truths[GR_MEETING]) {
		setGrMeeting();
	    }	
	    if (truths[GR_INACTIVE] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }
	    if (truths[GR_INACTIVE] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }			    
	    if (truths[GR_INACTIVE] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GR_INACTIVE] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }
	    if (truths[GR_INACTIVE] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }			
	    if (truths[GR_INACTIVE] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }

    }
    
    /** 
     * Toggles the value of the left behind attribute of this GroupBox object
     */
    public void setLeftBehind() {
	truths[GR_LEFT_VICTIM] = !truths[GR_LEFT_VICTIM];
	if (truths[GR_LEFT_VICTIM] == true) {
	    if(truths[GR_LEFT_VICTIM] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GR_LEFT_VICTIM] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GR_LEFT_VICTIM] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GR_LEFT_VICTIM] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GR_LEFT_VICTIM] == truths[GR_MEETING]) {
		setGrMeeting();
	    }	
	    if (truths[GR_LEFT_VICTIM] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }
	    if (truths[GR_LEFT_VICTIM] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }			    
	    if (truths[GR_LEFT_VICTIM] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }
	    if (truths[GR_LEFT_VICTIM] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GR_LEFT_VICTIM] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }			
	    if (truths[GR_LEFT_VICTIM] == truths[GR_LEFT_OBJECT]) {
		setLeftObject();
	    }		
	 }
    }

    /** 
     * Toggles the value of the left object attribute of this GroupBox object
     */
    public void setLeftObject() {
	truths[GR_LEFT_OBJECT] = !truths[GR_LEFT_OBJECT];
	if (truths[GR_LEFT_OBJECT] == true) {
	    if(truths[GR_LEFT_OBJECT] == truths[NONE_SIT]){
		setNoneSit();
	    }
	    if (truths[GR_LEFT_OBJECT] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[GR_LEFT_OBJECT] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[GR_LEFT_OBJECT] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[GR_LEFT_OBJECT] == truths[GR_MEETING]) {
		setGrMeeting();
	    }	
	    if (truths[GR_LEFT_OBJECT] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }
	    if (truths[GR_LEFT_OBJECT] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }			    
	    if (truths[GR_LEFT_OBJECT] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }
	    if (truths[GR_LEFT_OBJECT] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[GR_LEFT_OBJECT] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }			
	    if (truths[GR_LEFT_OBJECT] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }		
	 }
    }

    /** 
     * Toggles the value of the left object attribute of this GroupBox object
     */
    public void setNoneSit() {
	truths[NONE_SIT] = !truths[NONE_SIT];
	if (truths[NONE_SIT] == true) {
	    if(truths[NONE_SIT] == truths[GR_LEFT_OBJECT]){
		setLeftObject();
	    }
	    if (truths[NONE_SIT] == truths[GRBROWSING_SIT]) {
		setBrowsingSit();
	    }
	    if (truths[NONE_SIT] == truths[GR_FIGHTING]) {
		setGrFighting();
	    }
	    if (truths[NONE_SIT] == truths[GR_MOVING]) {
		setGrMoving();
	    }
	    if (truths[NONE_SIT] == truths[GR_MEETING]) {
		setGrMeeting();
	    }	
	    if (truths[NONE_SIT] == truths[GR_INTERACTING]) {
		setGrInteracting();
	    }
	    if (truths[NONE_SIT] == truths[GR_SPLITTING]) {
		setGrSplitting();
	    }			    
	    if (truths[NONE_SIT] == truths[GR_INACTIVE]) {
		setGrInactive();
	    }
	    if (truths[NONE_SIT] == truths[GRSHOPENTER_SIT]) {
		setShopenterSit();
	    }
	    if (truths[NONE_SIT] == truths[GRSHOPEXIT_SIT]) {
		setShopexitSit();
	    }			
	    if (truths[NONE_SIT] == truths[GR_LEFT_VICTIM]) {
		setLeftBehind();
	    }		
	 }
    }

    /** 
     * Toggles the value of the fighting attribute of this GroupBox object.
     */
    public void setFighting() {
	truths[FIGHTING] = !truths[FIGHTING];
	if (truths[FIGHTING] == true) {
	    if (truths[FIGHTING] == truths[NONE_SCE]) {
		setNoneSce();
	    }
	    if (truths[FIGHTING] == truths[GRWALKING_SCE]) {
		setWalkingSce();
	    }
	    if (truths[FIGHTING] == truths[MEETING]) {
		setMeeting();
	    }
	    if (truths[FIGHTING] == truths[GRWINDOWSHOP_SCE]) {
		setWindowshopSce();
	    }
	    if (truths[FIGHTING] == truths[GRSHOPENTER_SCE]) {
		setShopenterSce();
	    }	
	    if (truths[FIGHTING] == truths[GRSHOPEXIT_SCE]) {
		setShopexitSce();
	    }
	    if (truths[FIGHTING] == truths[GRSHOPREENTER_SCE]) {
		setShopreenterSce();
	    }			    
	    if (truths[FIGHTING] == truths[LEAVING]) {
		setLeaving();
	    }
	 }
    }

    /** 
     * Toggles the value of the meeting attribute of this GroupBox object.
     */
    public void setMeeting() {
	truths[MEETING] = !truths[MEETING];
	if (truths[MEETING] == true) {
	    if (truths[MEETING] == truths[NONE_SCE]) {
		setNoneSce();
	    }
	    if (truths[MEETING] == truths[FIGHTING]) {
		setFighting();
	    }
	    if (truths[MEETING] == truths[GRWALKING_SCE]) {
		setWalkingSce();
	    }
	    if (truths[MEETING] == truths[GRWINDOWSHOP_SCE]) {
		setWindowshopSce();
	    }
	    if (truths[MEETING] == truths[GRSHOPENTER_SCE]) {
		setShopenterSce();
	    }	
	    if (truths[MEETING] == truths[GRSHOPEXIT_SCE]) {
		setShopexitSce();
	    }
	    if (truths[MEETING] == truths[GRSHOPREENTER_SCE]) {
		setShopreenterSce();
	    }			    
	    if (truths[MEETING] == truths[LEAVING]) {
		setLeaving();
	    }
	 }

    }

    /** 
     * Toggles the value of the leaving attribute of this GroupBox object.
     */
    public void setLeaving() {
	truths[LEAVING] = !truths[LEAVING];
	if (truths[LEAVING] == true) {
	    if (truths[LEAVING] == truths[NONE_SCE]) {
		setNoneSce();
	    }
	    if (truths[LEAVING] == truths[FIGHTING]) {
		setFighting();
	    }
	    if (truths[LEAVING] == truths[GRWALKING_SCE]) {
		setWalkingSce();
	    }
	    if (truths[LEAVING] == truths[MEETING]) {
		setMeeting();
	    }
	    if (truths[LEAVING] == truths[GRWINDOWSHOP_SCE]) {
		setWindowshopSce();
	    }	
	    if (truths[LEAVING] == truths[GRSHOPENTER_SCE]) {
		setShopenterSce();
	    }
	    if (truths[LEAVING] == truths[GRSHOPEXIT_SCE]) {
		setShopexitSce();
	    }			    
	    if (truths[LEAVING] == truths[GRSHOPREENTER_SCE]) {
		setShopreenterSce();
	    }
	 }		
    }

    /** 
     * Toggles the value of the none scenario attribute of this GroupBox object.
     */
    public void setNoneSce() {
	truths[NONE_SCE] = !truths[NONE_SCE];
	if (truths[NONE_SCE] == true) {
	    if (truths[NONE_SCE] == truths[LEAVING]) {
		setLeaving();
	    }
	    if (truths[NONE_SCE] == truths[FIGHTING]) {
		setFighting();
	    }
	    if (truths[NONE_SCE] == truths[GRWALKING_SCE]) {
		setWalkingSce();
	    }
	    if (truths[NONE_SCE] == truths[MEETING]) {
		setMeeting();
	    }
	    if (truths[NONE_SCE] == truths[GRWINDOWSHOP_SCE]) {
		setWindowshopSce();
	    }	
	    if (truths[NONE_SCE] == truths[GRSHOPENTER_SCE]) {
		setShopenterSce();
	    }
	    if (truths[NONE_SCE] == truths[GRSHOPEXIT_SCE]) {
		setShopexitSce();
	    }			    
	    if (truths[NONE_SCE] == truths[GRSHOPREENTER_SCE]) {
		setShopreenterSce();
	    }
	 }		
    }

    /** 
    /** 
     * Toggles the value of the fight start attribute of this GroupBox object.
     */
    public void setFightStart() {
	truths[FIGHT_START] = !truths[FIGHT_START];
    }

    /** 
     * Toggles the value of the meeting attribute of this GroupBox object.
     */
    public void setFightEnd() {
	truths[FIGHT_END] = !truths[FIGHT_END];
    }

    
    /** 
     * Toggles the value of the meeting attribute of this GroupBox object.
     */
    public void setFightVictimLeft() {
	truths[FIGHT_VICTIM_LEFT] = !truths[FIGHT_VICTIM_LEFT];
    }

    /** 
     * Sets the value of the boxDrawn attribute of this GroupBox object
     * to value.
     */
    public void setBoxDrawn(boolean value) {
	boxDrawn = value;
    }
    
    /** 
     * Sets the value of the selected attribute of this GroupBox object
     * to value.
     */
    public void setSelected(boolean value) {
	selected = value;
    }

    /** 
     * Sets the value of the box attribute of this GroupBox object
     * to rectangle.
     */
    public void setBox(Rectangle rectangle) {
	box = rectangle;
	setBoxDrawn(true);
    }

    /** 
     * Sets the value of the axis attribute of this GroupBox object
     * to angle.
     */
    public void setAxis(int angle) {
	axis = angle;
    }

    /** 
     * Sets the value of the axisLine attribute of this GroupBox object
     * to axisLine.
     */
    public void setLine(Line2D.Float axisLine) {
	this.axisLine = axisLine;
    }

    /** 
     * Sets the individual boxes that are included in this group box
     */
    public void setIndBoxes(String[] indBoxString) {
	for (int i = 0; i < indBoxes.length; i++) {
	    indBoxes[i] = false;
	}
	for (int i = 0; i < indBoxString.length; i++) {
	    int boxNo = Integer.parseInt(indBoxString[i]);
	    if (boxNo < FrameData.SINGLE_BOXES) {
		indBoxes[boxNo] = true;
	    }
	}
    }

    public void setIndBoxes(int[] indBoxInt) {
	for (int i = 0; i < indBoxes.length; i++) {
	    indBoxes[i] = false;
	}
	for (int i = 0; i < indBoxInt.length; i++) {
	    if (indBoxInt[i] < FrameData.SINGLE_BOXES) {
		indBoxes[indBoxInt[i]] = true;
	    }
	}
    }
  
    /** 
     * Sets the value of the all the values in the truths array of this GroupBox object
     * to the value of newTruths
     */
    public void setTruths(boolean[] newTruths) {
	for (int i = 0; i < truths.length; i++) {
	    truths[i] = newTruths[i];
	}
    }

    /**
     * Returns the String representing this GroupBox object.
     */
    public String toString() {
	if (boxDrawn == false) {
	    return "";
	} else {
	    
	    // representation of the box and axis
	    String returnString = String.valueOf((int)box.getX()+(int)(box.getWidth()/2))+ // coords are now central not top left
		"\t"+String.valueOf((int)box.getY()+(int)(box.getHeight()/2))+
		"\t"+String.valueOf((int)box.getWidth())+"\t"+
		String.valueOf((int)box.getHeight()) + "\t" + axis;

	    // representation of individual box list
	    returnString = returnString+"\tgibl"; 
	    for (int i = 0; i < indBoxes.length; i++) {
		if (indBoxes[i]) {
		    returnString = returnString + "\t" + i;
		}
	    }
	    returnString = returnString + "\tegibl";

	    // appearance
	    if (truths[APPEAR] == true) returnString = returnString+"\tap";
	    if (truths[DISAPPEAR] == true) returnString = returnString+"\td";
	    
	    // movement
	    if (truths[ACTIVE] == true) returnString = returnString+"\tac";
	    if (truths[INACTIVE] == true) returnString = returnString+"\ti";
	    if (truths[MOVE] == true) returnString = returnString+"\tmo";
	    
	    // roles
	    if (truths[FIGHTERS] == true) returnString = returnString+"\tf\t1.0";
	    if (truths[MEETERS] == true) returnString = returnString+"\tme\t1.0";
	    if (truths[WALKERS] == true) returnString = returnString+"\tw\t1.0";
	    if (truths[GRBROWSER_ROLE] == true) returnString = returnString+"\tgbr\t1.0";
	    
	    // situations
	    if (truths[GR_FIGHTING] == true) returnString = returnString+"\tgf\t1.0";
	    if (truths[GR_MOVING] == true) returnString = returnString+"\tgmo\t1.0";
	    if (truths[GR_MEETING] == true) returnString = returnString+"\tgme\t1.0";
	    if (truths[GR_INTERACTING] == true) returnString = returnString+"\tgint\t1.0";	    
	    if (truths[GR_SPLITTING] == true) returnString = returnString+"\ts\t1.0";
	    if (truths[GR_INACTIVE] == true) returnString = returnString+"\tgi\t1.0";
	    if (truths[GR_LEFT_VICTIM] == true) returnString = returnString+"\tglv\t1.0";
	    if (truths[GR_LEFT_OBJECT] == true) returnString = returnString+"\tglo\t1.0";
	    if (truths[GRSHOPENTER_SIT] == true) returnString = returnString+"\tgent\t1.0";
	    if (truths[GRSHOPEXIT_SIT] == true) returnString = returnString+"\tgext\t1.0";
	    if (truths[GRBROWSING_SIT] == true) returnString = returnString+"\tgbst\t1.0";
	    // scenarios
	    if (truths[FIGHTING] == true) returnString = returnString+"\tfsc\t1.0";
	    if (truths[MEETING] == true) returnString = returnString+"\tmes\t1.0";
	    if (truths[LEAVING] == true) returnString = returnString+"\tls\t1.0";
	    if (truths[GRWINDOWSHOP_SCE] == true) returnString = returnString+"\tgwsp\t1.0";
	    if (truths[GRSHOPENTER_SCE] == true) returnString = returnString+"\tgsnt\t1.0";
	    if (truths[GRSHOPEXIT_SCE] == true) returnString = returnString+"\tgsxt\t1.0";
	    if (truths[GRSHOPREENTER_SCE] == true) returnString = returnString+"\tgren\t1.0";
	    if (truths[GRWALKING_SCE] == true) returnString = returnString+"\tgwk\t1.0";

	    // events
	    if (truths[FIGHT_START] == true) returnString = returnString+"\tfst\t1.0";
	    if (truths[FIGHT_END] == true) returnString = returnString+"\tfe\t1.0";
	    if (truths[FIGHT_VICTIM_LEFT] == true) returnString = returnString+"\tfv\t1.0";

	    return returnString;
	}
    }

	public String CheckRoles(){
	int j=0;
	String Roles="";
	for (int i=0;i<roles.length;i++)
		if (truths[roles[i]]==true){
			j++;
			Roles+=text[roles[i]]+" , ";
			}
		if (j<=1) 
			Roles=null; 
		return Roles;	
	}

	public String CheckSituations(){
	int j=0;
	String Situations="";
	for (int i=0;i<situations.length;i++)
		if (truths[situations[i]]==true){
			j++;
			Situations+=text[situations[i]]+" ,  ";
			}
		if (j<=1) 
			Situations=null; 
		return Situations;	
	}


	public String CheckScenarios(){
	int j=0;
	String Scenarios="";
	for (int i=0;i<scenarios.length;i++)
		if (truths[scenarios[i]]==true){
			j++;
			Scenarios+=text[scenarios[i]]+" , ";
			}
		if (j<=1) 
			Scenarios=null; 
		return Scenarios;	
	}

	public void setRol(String rol){
		System.out.println("Setting rol to "+rol);
		for (int i=0;i<roles.length;i++)
			if (rol.equals(text[roles[i]])==true){
				System.out.println("FOUND!");
				for (int j=0;j<roles.length;j++)
					truths[roles[j]]=false;			
				truths[roles[i]]=true;
				}
	}
		
	public void setSituation(String sit){
		System.out.println("Setting situation to "+sit);
		for (int i=0;i<situations.length;i++)
			if (sit.equals(text[situations[i]])==true){
				System.out.println("FOUND!");
				for (int j=0;j<situations.length;j++)
					truths[situations[j]]=false;			
				truths[situations[i]]=true;
				}
	}	
	
	public void setScenario(String sce){
		System.out.println("Setting scenario to "+sce);
		for (int i=0;i<scenarios.length;i++)
			if (sce.equals(text[scenarios[i]])==true){
				System.out.println("FOUND!");
				for (int j=0;j<scenarios.length;j++)
					truths[scenarios[j]]=false;			
				truths[scenarios[i]]=true;
				}
	}
			
}
