package xmlcaviargui;

import java.awt.*;
import javax.swing.*;

/** 
 *  Class used for loading picture onto the canvas.
 * @author Donald Nairn
 * @version 1.0
 */

public class ImageCanvas extends JLabel {
 

    /**
     * Represents the width of the image for this ImageCanvas.
     */
    protected int imageWidth = -1;
    
    /** 
     * Represents the height of the image for this ImageCanvas.
     */
    protected int imageHeight = -1;

    /**
     * Represents the jpg picture for this ImageCanvas.
     */
    protected ImageIcon imageIcon = null;

    /**
     * Default constructor.
     */
    public ImageCanvas() {
	super();
    }

    /**
     * Constructor takes an Image object and will create a new
     * ImageCanvas with this image as its background.
     */
    public ImageCanvas (Image image) {
	if (image != null) {
	    this.imageIcon = new ImageIcon(image);
	    imageWidth = image.getWidth(this)*CAVIARGUI.SCALE;
	    imageHeight = image.getHeight(this)*CAVIARGUI.SCALE;
	    super.setIcon(imageIcon);
	}
    }
    
    /** 
     * Loads the Image image into this ImageCanvas object,
     * replacing the old one.
     */
    public void loadImage(Image image) {
	if (image != null) {
	    this.imageIcon = new ImageIcon(image);
	    imageWidth = image.getWidth(this)*CAVIARGUI.SCALE;
	    imageHeight = image.getHeight(this)*CAVIARGUI.SCALE;
	    this.setIcon(imageIcon);
	}
    }

    /**
     * Overridden paint method.
     */
    public void paint(Graphics g) {
	if (imageIcon != null) {
	    this.setIcon(imageIcon);
	    Image image = imageIcon.getImage();
	    g.setColor(Color.WHITE);
	    g.drawImage(image,0,0,imageWidth,imageHeight,this);
	}
    }

    /**
     * Returns the image width.
     */
    public int getImageWidth(){
	return imageWidth;
    }
    
    /**
     * Returns the image height.
     */
    public int getImageHeight() {
	return imageHeight;
    }

}
